Learn R Programming

blapsr (version 0.6.1)

print.gamlps: Print a generalized additive model object.

Description

Print a generalized additive model object.

Usage

# S3 method for gamlps
print(x, ...)

Arguments

x

An object of class gamlps.

...

Further arguments to be passed to print.

Author

Oswaldo Gressani oswaldo_gressani@hotmail.fr.

Details

Prints informative output of a fitted generalized additive model. In particular, the model formula, sample size, number of B-splines in basis, number of smooth terms, the chosen penalty order, the latent field dimension, model degrees of freedom, the estimated coefficients of the linear part and the estimated effective degrees of freedom of the smooth terms are displayed.

See Also

gamlps, gamlps.object, plot.gamlps