Print a generalized additive model object.
# S3 method for gamlps
print(x, ...)An object of class gamlps.
Further arguments to be passed to print.
Oswaldo Gressani oswaldo_gressani@hotmail.fr.
Prints informative output of a fitted generalized additive model. In particular, the model formula, sample size, number of B-splines in basis, number of smooth terms, the chosen penalty order, the latent field dimension, model degrees of freedom, the estimated coefficients of the linear part and the estimated effective degrees of freedom of the smooth terms are displayed.
gamlps, gamlps.object,
plot.gamlps